@@ -328,6 +328,12 @@ hint = (\x -> f =<< g x) ==> f Control.Monad.<=< g where _ = noQuickCheck
 warn = a >> forever a ==> forever a where _ = noQuickCheck
 hint = liftM2 id ==> ap where _ = noQuickCheck
 warn = mapM (uncurry f) (zip l m) ==> zipWithM f l m where _ = noQuickCheck
+warn = mapM_ (void . f) ==> mapM_ f
+warn = mapM_ (void f) ==> mapM_ f
+warn = forM_ x (void . f) ==> forM_ x f
+warn = forM_ x (void f) ==> forM_ x f
+warn = void (mapM f x) ==> mapM_ f x
+warn = void (forM x f) ==> forM_ x f
 
 -- STATE MONAD
 
@@ -724,5 +730,8 @@ import qualified Data.Text.Lazy as DTL \
 main = DTL.concat $ map (`DTL.snoc` '-') [DTL.pack "one", DTL.pack "two", DTL.pack "three"]
 import Text.Blaze.Html5.Attributes as A \
 main = A.id (stringValue id')
+import Prelude((==)) \
+import qualified Prelude as P \
+main = P.length xs == 0 -- P.null xs
 </TEST>
 -}
